@@ -2,15 +2,19 @@ from . import dirs
 from . import fechas
 
 from .cl_ReporteBase import *
+from .cl_BCRA import *
 
 __all__ = ['DTE',]
 
-class DTE(ReporteBase):
+class DTE(ReporteBase,BCRA):
 
     def __init__(
         self,
         fecha_i = fechas.hoy(),
         fecha_f = fechas.hoy(),
+        cargar=False,
+        descargar=False,
+        dolarizar=None,
         periodo=None,
         filtro = 'ultimos',
         parques = [],
@@ -21,7 +25,7 @@ class DTE(ReporteBase):
 
         dir_descarga, dir_extraccion = self.__elegir_dirs(filtro=None)
 
-        super().__init__(
+        ReporteBase.__init__(self,
             fecha_i = fecha_i,
             fecha_f = fecha_f,
             periodo=periodo,
@@ -42,6 +46,19 @@ class DTE(ReporteBase):
         
         self.filtro = filtro
         
+        try :
+            self.tc = BCRA(cargar_tc=True).tc_udh.copy(deep=True)
+        except:
+            print('No se pudo cargar el Tipo de Cambio según la comunicación 3500 A del BRCRA.')
+            self.tc = None
+        
+        
+        if cargar:
+            self.cargar(descargar=descargar,filtro=filtro,exportar_consulta=False,dolarizar=dolarizar)
+            
+        if not cargar and descargar:
+            self.descargar(filtro=filtro)
+        
     #--------------------------
     #
     #Fin de la función __init__
@@ -98,7 +115,7 @@ class DTE(ReporteBase):
         if filtro is not None:
             self.filtro = filtro
         
-        super().consultar(
+        ReporteBase.consultar(self,
             exportar_consulta=exportar_consulta,
             dir_consulta=dir_consulta,
             filtro=self.filtro
@@ -109,29 +126,59 @@ class DTE(ReporteBase):
         if filtro is not None:
             self.filtro = filtro
         
-        super().descargar(
+        ReporteBase.descargar(self,
             exportar_consulta=exportar_consulta,
             dir_consulta=dir_consulta,
             filtro=self.filtro
             ) 
         
-    def cargar(self,descargar=False,filtro=None,exportar_consulta=False):
+    def cargar(self,descargar=False,filtro=None,exportar_consulta=False,dolarizar=None):
         
         if filtro is not None:
             self.filtro = filtro
         
-        super().cargar(
+        ReporteBase.cargar(self,
             descargar=descargar,
             filtro=self.filtro,
             exportar_consulta=exportar_consulta
             )
+        
+        if isinstance(dolarizar,str):
+            dolarizar = [dolarizar,]
+        
+        if isinstance(dolarizar,(list,tuple,set)):
+            
+            #Chequeo de que se pudo cargar el tipo de cambio
+            if self.tc is None:
+                try :
+                    self.tc = BCRA(cargar_tc=True).tc_udh.copy(deep=True)
+                except:
+                    raise Exception('No se pudo cargar el Tipo de Cambio según la comunicación 3500 A del BRCRA.')
+            
+            #Chequeo de columnas
+            for col in dolarizar:
+                if not isinstance(col,str):
+                    raise TypeError(f'El parámetro "dolarizar" debe contenir una lista de strings, pero {col} es del tipo {type(col)}')
+                
+                if col not in self.datos.columns:
+                    raise ValueError(f'No se encontró la columna {col} entre {self.datos.columns.to_list()}')
+  
+            self.datos = (self.datos
+                .merge(
+                    right=self.tc, 
+                    left_on='Fecha', 
+                    right_index=True, 
+                    how='left')
+                .assign(**{f'{c}_USD':lambda df_, c=c: df_[c].div(df_.TC) for c in dolarizar})
+                .rename(columns={c:f'{c}_ARS' for c in dolarizar})
+            )
     
     def a_excel(self,descargar=False,filtro=None,exportar_consulta=False):
         
         if filtro is not None:
             self.filtro = filtro
         
-        super().a_excel(
+        ReporteBase.a_excel(self,
             descargar=descargar,
             filtro=self.filtro,
             exportar_consulta=exportar_consulta
