@@ -11,6 +11,8 @@ class PPO(ReporteBase):
         self,
         fecha_i = fechas.hoy(),
         fecha_f = fechas.hoy(),
+        cargar=False,
+        descargar=False,
         periodo=None,
         parques = [],
         filtro = 'ultimos',
@@ -42,6 +44,14 @@ class PPO(ReporteBase):
             )
         
         self.filtro = filtro
+        
+        if cargar:
+            self.cargar(descargar=descargar,filtro=filtro,exportar_consulta=False)
+            
+        if not cargar and descargar:
+            self.descargar(filtro=filtro)
+        
+        
     #--------------------------
     #
     #Fin de la función __init__
