@@ -40,7 +40,11 @@ class ReporteBase(ApiCammesa):
         self._nemo_rpt = nemo_rpt
         self._nombre = nombre
         self._formato_nombre_archivo = formato_nombre_archivo
-        self._parques = parques
+        
+        if isinstance(parques,str):
+            self._parques = [parques,]
+        else:
+            self._parques = parques
         self._extension = extension
         self._tabla_datos = tabla_datos
         self._tabla_fecha = tabla_fecha
